; ==============================================================================
; Configuration options for the K7D patcher
; Copyright 2004 Emboss, all rights reserved
; See licence.txt for details.
; ==============================================================================

; - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
; What-to-include options
; - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -

%ifndef CMD_LINE_CONFIG
  %define PATCH_MOBILE
  %define PATCH_FIDVID
  %define USE_KEYBOARD      ; Set if you wish to enable the keyboard checking
  %define USE_SBU           ; Set if you wish to use Serial BIOS Upload
;  %define DOSTEST           ; Set to do a "dry run" DOS test file
%endif

; - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
; FID and VID options (only used if PATCH_FIDVID defined)
; - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -

;%define FID_MAX           ; Set if you wish to use the maximum multiplier on
                          ; boot.
%define FID_STARTUP       ; Set if you wish to use the "startup" multiplier on
                          ; boot.
;%define FID_SET 180       ; Set if you wish to use a specific multiplier on
                          ; boot. Set it to 10 times the desired multiplier.
                          ; Available values are 30,40,50,55,60,65,70,75,80,85,
                          ; 90,95,100,105,110,115,120,125,130,135,140,150,160,
                          ; 165,170,180,190,200,210,220,230,240

;%define VID_MAX           ; Set if you wish to use the maximum voltage on boot.
%define VID_STARTUP       ; Set if you wish to use the "startup" voltage on
                          ; boot.
;%define VID_SET 1650      ; Set if you wish to use a specific voltgae on boot.
                          ; Set it to 1000 times the desired voltage. Available
                          ; values are 2000,1950,1900,1850,1800,1750,1700,1650,
                          ; 1600,1550,1500,1450,1400,1350,1300,1275,1250,1225,
                          ; 1200,1175,1150,1125,1100,1075,1050,1024,1000,975,
                          ; 950,925

; - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
; Check sanity of defined options
; - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -

%ifndef USE_KEYBOARD
  %undef USE_SBU
%endif

%ifdef PATCH_FIDVID

  %ifdef FID_MAX
    %ifdef FID_STARTUP
      %error Multiple startup multiplier options specified.
    %elifdef FID_SET
      %error Multiple startup multiplier options specified.
    %endif
  %elifdef FID_STARTUP
    %ifdef FID_SET
      %error Multiple startup multiplier options specified.
    %endif
  %elifndef FID_SET
    %error No startup multiplier option specified.
  %endif

  %ifdef VID_MAX
    %ifdef VID_STARTUP
      %error Multiple startup voltage options specified.
    %elifdef VID_SET
      %error Multiple startup voltage options specified.
    %endif
  %elifdef VID_STARTUP
    %ifdef VID_SET
      %error Multiple startup voltage options specified.
    %endif
  %elifndef VID_SET
    %error No voltage startup option specified.
  %endif

%endif

; - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
; Decide which drivers to include
; - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
%ifdef USE_KEYBOARD
  %define DRV_KEYBOARD
%endif
%ifdef USE_SBU
  %define DRV_SERIAL
%endif

; - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
; Multiplier to FID-code conversion
; - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -

%ifdef PATCH_FIDVID

  %ifdef FID_SET
    %if FID_SET = 30
      %define FID_CODE 0x10
    %elif FID_SET = 40
      %define FID_CODE 0x12
    %elif FID_SET = 50
      %define FID_CODE 0x04
    %elif FID_SET = 55
      %define FID_CODE 0x05
    %elif FID_SET = 60
      %define FID_CODE 0x06
    %elif FID_SET = 65
      %define FID_CODE 0x07
    %elif FID_SET = 70
      %define FID_CODE 0x08
    %elif FID_SET = 75
      %define FID_CODE 0x09
    %elif FID_SET = 80
      %define FID_CODE 0x0A
    %elif FID_SET = 85
      %define FID_CODE 0x0B
    %elif FID_SET = 90
      %define FID_CODE 0x0C
    %elif FID_SET = 95
      %define FID_CODE 0x0D
    %elif FID_SET = 100
      %define FID_CODE 0x0E
    %elif FID_SET = 105
      %define FID_CODE 0x0F
    %elif FID_SET = 110
      %define FID_CODE 0x00
    %elif FID_SET = 115
      %define FID_CODE 0x01
    %elif FID_SET = 120
      %define FID_CODE 0x02
    %elif FID_SET = 125
      %define FID_CODE 0x03
    %elif FID_SET = 130
      %define FID_CODE 0x14
    %elif FID_SET = 135
      %define FID_CODE 0x15
    %elif FID_SET = 140
      %define FID_CODE 0x16
    %elif FID_SET = 150
      %define FID_CODE 0x18
    %elif FID_SET = 160
      %define FID_CODE 0x1A
    %elif FID_SET = 165
      %define FID_CODE 0x1B
    %elif FID_SET = 170
      %define FID_CODE 0x1C
    %elif FID_SET = 180
      %define FID_CODE 0x1D
    %elif FID_SET = 190
      %define FID_CODE 0x11
    %elif FID_SET = 200
      %define FID_CODE 0x13
    %elif FID_SET = 210
      %define FID_CODE 0x17
    %elif FID_SET = 220
      %define FID_CODE 0x19
    %elif FID_SET = 230
      %define FID_CODE 0x1E
    %elif FID_SET = 240
      %define FID_CODE 0x1F
    %else
      %error Invalid fixed multiplier specified.
    %endif
  %endif

%endif

; - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
; Voltage to VID-code conversion
; - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -

%ifdef PATCH_FIDVID

  %ifdef VID_SET
    %if VID_SET = 2000
      %define VID_CODE 0x00
    %elif VID_SET = 1950
      %define VID_CODE 0x01
    %elif VID_SET = 1900
      %define VID_CODE 0x02
    %elif VID_SET = 1850
      %define VID_CODE 0x03
    %elif VID_SET = 1800
      %define VID_CODE 0x04
    %elif VID_SET = 1750
      %define VID_CODE 0x05
    %elif VID_SET = 1700
      %define VID_CODE 0x06
    %elif VID_SET = 1650
      %define VID_CODE 0x07
    %elif VID_SET = 1600
      %define VID_CODE 0x08
    %elif VID_SET = 1550
      %define VID_CODE 0x09
    %elif VID_SET = 1500
      %define VID_CODE 0x0A
    %elif VID_SET = 1450
      %define VID_CODE 0x0B
    %elif VID_SET = 1400
      %define VID_CODE 0x0C
    %elif VID_SET = 1350
      %define VID_CODE 0x0D
    %elif VID_SET = 1300
      %define VID_CODE 0x0E
    %elif VID_SET = 1275
      %define VID_CODE 0x10
    %elif VID_SET = 1250
      %define VID_CODE 0x11
    %elif VID_SET = 1225
      %define VID_CODE 0x12
    %elif VID_SET = 1200
      %define VID_CODE 0x13
    %elif VID_SET = 1175
      %define VID_CODE 0x14
    %elif VID_SET = 1150
      %define VID_CODE 0x15
    %elif VID_SET = 1125
      %define VID_CODE 0x16
    %elif VID_SET = 1100
      %define VID_CODE 0x17
    %elif VID_SET = 1075
      %define VID_CODE 0x18
    %elif VID_SET = 1050
      %define VID_CODE 0x19
    %elif VID_SET = 1024
      %define VID_CODE 0x1A
    %elif VID_SET = 1000
      %define VID_CODE 0x1B
    %elif VID_SET = 975
      %define VID_CODE 0x1C
    %elif VID_SET = 950
      %define VID_CODE 0x1D
    %elif VID_SET = 925
      %define VID_CODE 0x1E
    %else
      %error Invalid fixed voltage specified.
    %endif
  %endif

%endif

; - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
; Useful macros
; - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
%macro IODELAY 0
  out   0xEB,al
  out   0xEB,al
%endmacro

%ifdef DOSTEST
%macro SHOWSTR 1
  jmp     %%SkipString
%%DataStr:
  db %1, 0x0D, 0x0A, '$'
%%SkipString:
  pusha
  push    ds
  push    cs
  pop     ds
  mov     dx,%%DataStr
  mov     ah,9
  int     0x21
  pop     ds
  popa
%endmacro
%else
%macro SHOWSTR 1
%endmacro
%endif
