; ==============================================================================
; The keyboard processing module
; Copyright 2004 Emboss, all rights reserved
; See licence.txt for details.
; ==============================================================================

; - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
; Mod_Keyboard
;   The main keyboard processing function.
;   Called with nothing
;   Returns nothing
;   Destroys ax, dx
; - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
mod_Keyboard:
  SHOWSTR "mod_Keyboard"
  call    KbdInit
  jnz     .ExitBreak                ; Keyboard not working, bail out

  mov     dl,5                      ; Read up to 5 keys
.KeyLoop:
%ifdef USE_SBU
  mov     al,[KbdOverride]          ; Process any key overrides
  or      al,al
  jz      .NoOverride
  mov     BYTE [KbdOverride],0
  jmp     .ProcessKey
.NoOverride:
%endif
  call    KbdRead                   ; See if any keys have been pressed
  jnz     .NextRead
%ifdef USE_SBU
.ProcessKey:
  SHOWSTR ".ProcessKey"
%endif
  cmp     al,0x4A                   ; numpad "-" key?
  je      .ExitBreak                ; If so, skip any patches
  cmp     al,0x01                   ; escape key?
  je      .ForceReflash             ; If so, force reflash
%ifdef USE_SBU
  cmp     al,0x2E                   ; "c" key?
  je      .BeginSBU                 ; If so, go to SBU module
%endif
.NextRead:
  dec     dl
  jnz     .KeyLoop

  mov     WORD [NextModule],mod_Patches ; By default, apply patches
  
.ExitContinue:
  xor     al,al                     ; Set ZF (=continue main loop)
  ret

.ExitBreak:
  or      al,1                      ; Clear ZF (=abort main loop)
  ret

%ifdef USE_SBU
.BeginSBU:
  SHOWSTR ".BeginSBU"
  mov     WORD [NextModule],mod_SBU
  jmp     .ExitContinue
%endif

.ForceReflash:
  SHOWSTR ".ForceReflash"
  mov     WORD [NextModule],mod_ForceReflash
  jmp     .ExitContinue
