; ==============================================================================
; The patch applicator module.
; Copyright 2004 Emboss, all rights reserved
; See licence.txt for details.
; ==============================================================================

; - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
; Update any checksums in the BIOS. Called with ax = upper 64kb segment
; - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
UpdateChecksums:
%ifndef DOSTEST
  push    si
  push    cx
  push    bx
  push    es

  mov     es,ax
  xor     bl,bl

  ; Update the version line checksum
  mov     si,0xE061
  movzx   cx,BYTE [es:0xE060]
  call    ChecksumRgn

  ; Update the revision line checksum
  mov     si,0xE0C1
  mov     cx,78
  call    ChecksumRgn

  ; Update the E-F page checksum
  mov     si,0xE000
  mov     cx,0x1FEE
  call    ChecksumRgn

  ; Update the checksum-checksum
  neg     bl
  mov     [es:0xFFEF],bl

  ; Update the top-64kb checksum
  mov     si,0x0000
  mov     cx,0xFFFF
  call    ChecksumRgn

  pop     es
  pop     bx
  pop     cx
  pop     si
%endif
  ret

ChecksumRgn:
  xor     ah,ah
.CSumLoop:
  mov     al,[es:si]
  add     ah,al
  dec     cx
  jnz     .CSumLoop
  neg     ah
  mov     [es:si],ah
  add     bl,ah
  ret

; - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
; Apply the required patches
; - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
mod_Patches:
  SHOWSTR "mod_Patches"

  push    si
  push    di
  push    bx
  push    cx
  push    es

  mov     bx,PatchDefs
.PatchLoop:
  mov     si,[bx]
  cmp     si,0xFFFF
  je      .PatchesDone
  mov     ax,[bx+2]
  mov     es,ax
  mov     di,[bx+4]
  mov     cx,[bx+6]
  add     bx,BYTE 8
  rep     movsb

  jmp     .PatchLoop

.PatchesDone:
  ; Update checksums
  mov     ax,0x6000
  call    UpdateChecksums

  pop     es
  pop     cx
  pop     bx
  pop     di
  pop     si
  or      al,1                      ; Clear ZF (=abort main loop)
  ret
  
%ifdef DOSTEST
; - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
; DOS dry-run patchdefs
; - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
testpatch:
  db 'X', 0x07, 'Y', 0x07, 'Z', 0x07

; source offset, destination segment, destination offset, bytes
PatchDefs:
  dw  testpatch, 0xB800, 0x0000, 6
  dw  0xFFFF
  
%else
; - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
; The actual patch data (assembled previously)
; - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -

%ifdef PATCH_MOBILE
m_580A7: incbin "patches/mobile/m_580A7"    ; checked,  OK
m_5803D: incbin "patches/mobile/m_5803D"    ; checked,  OK
m_5859B: incbin "patches/mobile/m_5859B"    ; checked,  OK
m_5A08B: incbin "patches/mobile/m_5A08B"    ; checked,  OK
m_end:
%endif

%ifdef PATCH_FIDVID
fv_53D1D: incbin "patches/fidvid/fv_53D1D"  ; checked,  OK
fv_64B8B: incbin "patches/fidvid/fv_64B8B"  ; checked,  OK
fv_end:
%endif

NameStr:
  db  (EndOfName - NameStr)
  db  'W6501MS V1.91 100903 10:38:36 (emboss K7D_'
%ifdef PATCH_MOBILE
  db  'M'
%endif
%ifdef PATCH_FIDVID
  db  'F'
%endif
%ifdef USE_KEYBOARD
  db  'K'
%endif
%ifdef USE_SBU
  db  'S'
%endif

%ifdef FID_SET
  db  ' F=FID_SET'
%endif
%ifdef FID_MAX
  db  ' F=ML6'
%endif
%ifdef FID_STARTUP
  db  ' F=SL3'
%endif

%ifdef VID_SET
  db  ' V=VID_SET'
%endif
%ifdef VID_MAX
  db  ' V=ML8'
%endif
%ifdef VID_STARTUP
  db  ' V=SL11'
%endif

  db  ')'
EndOfName:
  TIMES 79-($-NameStr) db 0
  
; source offset, destination segment, destination offset, bytes
PatchDefs:
%ifdef PATCH_MOBILE
  dw  m_580A7, 0x5000, 0x80A7, m_5803D-m_580A7
  dw  m_5803D, 0x5000, 0x803D, m_5859B-m_5803D
  dw  m_5859B, 0x5000, 0x859B, m_5A08B-m_5859B
  dw  m_5A08B, 0x5000, 0xA08B, m_end  -m_5A08B
%endif

%ifdef PATCH_FIDVID
  dw  fv_53D1D, 0x5000, 0x3D1D, fv_64B8B-fv_53D1D
  dw  fv_64B8B, 0x6000, 0x4B8B, fv_end  -fv_64B8B
%endif

  dw  NameStr, 0x6000, 0xE0C0, 79

  dw  0xFFFF
%endif

