; ==============================================================================
; The main patch code. Gets executed just prior to the BIOS being moved. Gets
; unpacked into 4E00:0000
; Copyright 2004 Emboss, all rights reserved
; See licence.txt for details.
; ==============================================================================

; - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
; Configuration stuff
; - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -

%include "config.inc"

%ifdef DOSTEST
org 0x100
%else
org 0
%endif

; - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
; Have the SBU header if SBU is being used
; - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -

%ifdef USE_SBU
  jmp     SHORT AfterSelfHeader
KbdOverride:
  db      0                         ; Set to a nonzero value to pretend that
                                    ; this scancode came from the keyboard.
FinishDest:
  dw      0                         ; Where to jump to when everything is done.

SerialBase:
  dw      0

Padding:
  db      0,0,0,0,0,0               ; Pad to 32 bytes

SBUSelfUpdate:                      ; This code is called when doing an update
.ReadLoop:                          ; of the main SBU program. Obviously the
  add     dl,ah                     ; standard SBU code can't be used, as this
.InputPoll1:                        ; is about to be overwritten. Requires ah=5,
  in      al,dx                     ; dx = base port, cx = number of bytes,
  test    al,1                      ; di = AfterSelfHeader
  jz      .InputPoll1
  sub     dl,ah
  in      al,dx
  stosb
  loop    .ReadLoop
  pop     es
  pop     ds
  popad
  popfd
AfterSelfHeader:
%endif

; - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
; The main code begins here
; - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
%ifdef DOSTEST
  jmp     mod_DOS
%endif

Start:
  pushfd                            ; Save registers
  pushad
  push    ds
  push    es

  mov     ax,ds
  push    cs                        ; Set ds=cs
  pop     ds

  cli
  cld
%ifdef USE_SBU
  mov     WORD [FinishDest],NormalFinish  ; Set the "finish" address
%endif
  cmp     ax,0x5000
  je      DispatchLoop
%ifdef USE_SBU
  jmp     [FinishDest]              ; If checksum error then don't do anything
%else
  jmp     NormalFinish
%endif

DispatchLoop:
  SHOWSTR "Dispatching"
  call    [NextModule]
  jz      DispatchLoop

%ifdef USE_SBU
  jmp     [FinishDest]
%endif

NormalFinish:
  SHOWSTR "Finishing"

%ifndef DOSTEST
  ; Restore the old code
  mov     ax,0x2000
  mov     es,ax
  mov     si,OldDataD760
  mov     di,0xD760
  mov     cx,48
  rep     movsb
%endif
  pop     es
  pop     ds
  popad
  popfd

OldCode:
  mov     si, ds
  mov     di, 0E000h
  retf                              ; Let the normal code continue!

NextModule:
%ifdef USE_KEYBOARD
  dw  mod_Keyboard
%else
  dw  mod_Patches
%endif

OldDataD760:

  db 0x81, 0xf9, 0x6f, 0x02, 0x00, 0x00, 0x76, 0xf3
  db 0x1e, 0x8c, 0xde, 0xbf, 0x00, 0xe0, 0xb9, 0x00
  db 0x80, 0xe8, 0x13, 0x20, 0x1f, 0x8c, 0xde, 0x81
  db 0xc6, 0x00, 0x10, 0xbf, 0x00, 0xf0, 0xb9, 0x00
  db 0x80, 0xe8, 0x03, 0x20, 0x66, 0xb8, 0x10, 0x10
  db 0x10, 0x10, 0x66, 0x8b, 0xd0, 0x66, 0xb9, 0x6c

; - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
; The various modules
; - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
%include "modules\patches.asm"
%ifdef DOSTEST
  %include "modules\DOS.asm"
%endif
%ifdef USE_SBU
  %include "modules\SBU.asm"
%endif
%ifdef USE_KEYBOARD
  %include "modules\keyboard.asm"
  %include "modules\forcereflash.asm"  
%endif

; - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
; The various drivers
; - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
%ifdef DRV_SERIAL
  %include "drivers\serial.asm"
%endif
%ifdef DRV_KEYBOARD
  %include "drivers\keyboard.asm"
%endif

%ifndef DOSTEST
  TIMES 4096-($-$$) DB 0
%endif
